/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.task;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.Box;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JSpinner.DefaultEditor;
import javax.swing.SpinnerListModel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.util.swing.FormRow;
import org.openide.util.NbBundle;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class WorkWidthPanel extends javax.swing.JPanel {

    //String values are used because an array of double values is not displayed
    //properly by the spinner. String values are used that are later converted
    //to double values
    private static final String[] DEFAULT_WORK_WIDTH_VALUES = {"5.0", "10.0", "20.0", "25.0"};
    private static final Logger LOGGER = Logger.getLogger(WorkWidthPanel.class.getCanonicalName());

    private final SpinnerListModel workWidthSpinnerModel;

    /**
     * Creates new form WorkWidthPanel
     */
    public WorkWidthPanel() {
        this(DEFAULT_WORK_WIDTH_VALUES);
    }
    
    /**
     * Creates new form WorkWidthPanel
     */
    public WorkWidthPanel(String[] values) {
        workWidthSpinnerModel = new SpinnerListModel(Arrays.asList(values));
//        initComponents();
        // using alternative layout to make the panel parts line up with FormRow components:
        init();

        //disable editing the text field of the spinner
        ((DefaultEditor) workWidthSpinner.getEditor()).getTextField().setEditable(false);

        workWidthSpinner.setModel(workWidthSpinnerModel);
    }
    
    private void init() {
        setLayout(new MigLayout("wrap 2, insets 0 0 0 0"));
        workWidthSpinner = new javax.swing.JSpinner();
        workWidthSpinner.setPreferredSize(new Dimension(72, FormRow.ROW_HEIGHT));
        workWidthSpinner.setMinimumSize(new Dimension(72, FormRow.ROW_HEIGHT));
        workWidthLabel = new JLabel(NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthLabel.text"));
        workWidthMeasurementLabel = new JLabel(NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthMeasurementLabel.text"));
        JPanel spinnerPanel = new JPanel(new MigLayout("wrap 2, insets 0 0 0 0"));
        setBackground(java.awt.Color.white);
        spinnerPanel.setBackground(java.awt.Color.white);
        spinnerPanel.add(workWidthSpinner);
        spinnerPanel.add(workWidthMeasurementLabel);
        
        add(new FormRow(false, workWidthLabel, spinnerPanel));
    }

    public double getWorkWidthValue() {
        String spinnerStringValue = (String) workWidthSpinner.getValue();
        return Double.valueOf(spinnerStringValue);
    }

    public void setWorkWidthValue(double value) {
        String workWidth = Double.toString(value);
        if (!workWidthSpinnerModel.getList().contains(workWidth)) {
            LOGGER.log(Level.WARNING, "Work width spinner does not contain work width value {0}", workWidth);
        } else {
            workWidthSpinner.setValue(workWidth);
        }
    }

    public JSpinner getWorkWidthSpinner() {
        return workWidthSpinner;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        workWidthLabel = new javax.swing.JLabel();
        workWidthMeasurementLabel = new javax.swing.JLabel();
        workWidthSpinner = new javax.swing.JSpinner();

        setBackground(java.awt.Color.white);

        workWidthLabel.setText(org.openide.util.NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthLabel.text")); // NOI18N

        workWidthMeasurementLabel.setText(org.openide.util.NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthMeasurementLabel.text")); // NOI18N

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(workWidthLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(workWidthSpinner, javax.swing.GroupLayout.DEFAULT_SIZE, 72, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(workWidthMeasurementLabel)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                .addComponent(workWidthLabel)
                .addComponent(workWidthSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addComponent(workWidthMeasurementLabel))
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel workWidthLabel;
    private javax.swing.JLabel workWidthMeasurementLabel;
    private javax.swing.JSpinner workWidthSpinner;
    // End of variables declaration//GEN-END:variables

}
